import { ChangeDetectorRef, Component } from '@angular/core';
import { ICellRendererAngularComp } from 'ag-grid-angular';
import { ICellRendererParams } from 'ag-grid-community';

interface CommentCellParams extends ICellRendererParams {
  value: string;
}

@Component({
  selector: 'app-comment-cell',
  template: `
    <div class="comment-cell" [attr.title]="params.value">
      <div
        #commentText
        tabindex="0"
        role="button"
        [class.expanded]="expanded"
        [class.long-text]="isLongText"
        [attr.aria-expanded]="expanded"
        (click)="toggleExpand()"
        (keydown.enter)="toggleExpand()"
        (keydown.space)="toggleExpand()"
      >
        {{ this.params.value }}
      </div>
    </div>
  `,
  styles: [
    `
      .comment-cell {
        white-space: normal;
        line-height: normal;
      }
      .comment-cell > div {
        text-overflow: ellipsis;
        display: -webkit-box;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        cursor: pointer;
        transition: all 0.5s ease;
      }
      .comment-cell > div.expanded {
        padding-bottom: 0.5em;
        -webkit-line-clamp: unset;
      }
      .comment-cell > div.long-text:not(.expanded)::after {
        content: '...';
      }
    `,
  ],
})
export class CommentCellRendererComponent implements ICellRendererAngularComp {
  params!: CommentCellParams;
  expanded = false;
  isLongText = false;
  displayText = '';

  constructor(private cdr: ChangeDetectorRef) {}

  agInit(params: CommentCellParams): void {
    this.params = params;
    this.isLongText = params.value && params.value.length > 100;
  }

  toggleExpand(): void {
    this.expanded = !this.expanded;
    this.cdr.detectChanges();
  }

  refresh(params: CommentCellParams): boolean {
    this.params = params;
    this.isLongText = params.value && params.value.length > 100;
    return true;
  }
}
